/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Kleber $
 *  Last update : $Date: 2000/06/06 10:29:43 $
 *  Revision :    $Revision: 1.2 $
 *  State:        $State: Exp $
*/
package main;
import javax.swing.text.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
/**
* Contains a document for DICOM Code String (CS) values.
* A CS contains uppercase characters, digtis, Spaces and "_"
* @author Klaus Kleber
*/
public class CSDocument extends PlainDocument
{
    
    private int maxSize = 16;
    /**
    * Contstructor.
    */
    public CSDocument()
    {
        super();
    }
    /**
    * Insert a String and checks if the String is a valid input.
    */
    public void insertString(int offset, String s, AttributeSet attributeSet) throws BadLocationException
    {
        char c;
        if (s == null) return;
        
        int size = s.length();
        
        for (int j = 0; j < size; j++)
        {
            if (offset+j >= maxSize) 
            {
                    Toolkit.getDefaultToolkit().beep();
                    return;
            }
            
            try   
            {
                c = s.charAt(j);
                if ((c != '_' )&&(c!=' '))
                {
                    if (!Character.isDigit(c))
                    {
                        if (Character.isLetter(c))
                        {
                            c = Character.toUpperCase(c);
                        }
                        else
                        {
                            Toolkit.getDefaultToolkit().beep();
                            return;
                        }
                    }
                }
            }
            catch(Exception e)
            {
                
                    Toolkit.getDefaultToolkit().beep();
                    return;
            }
            super.insertString(offset+j, new Character(c).toString(), attributeSet);
        }
    }
    
    
    
}
/*
 *  CVS Log
 *  $Log: CSDocument.java,v $
 *  Revision 1.2  2000/06/06 10:29:43  Kleber
 *  add: apply display area, windowing and annotations to frames
 *  and more than one image
 *
 *  Revision 1.1.1.1  2000/06/02 07:02:13  Kleber
 *  new CVS init
 *
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *
*/
