/*
 *
 *  Copyright (C) 1999, Institute for MicroTherapy
 *
 *  This software and supporting documentation were developed by
 *
 *    University of Witten/Herdecke
 *    Department of Radiology and MicroTherapy
 *    Institute for MicroTherapy
 *    Medical computer science
 *    
 *    Universitaetsstrasse 142
 *    44799 Bochum, Germany
 *    
 *    http://www.microtherapy.de/go/cs
 *    mailto:computer.science@microtherapy.de
 *
 *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND THE INSTITUTE MAKES  NO 
 *  WARRANTY REGARDING THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY
 *  OR FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES 
 *  OR ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY 
 *  AND PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
 *
 *  Author :      $Author: Kleber $
 *  Last update : $Date: 2000/06/02 07:02:14 $
 *  Revision :    $Revision: 1.1.1.1 $
 *  State:        $State: Exp $
*/
package main;
import javax.swing.*;
import java.awt.*;
import javax.swing.border.*;
import java.util.*;
/**
* Contains the GUI for the status line
*/
public class StatusLine extends JPanel implements StatusListener, MainListener
{
    
    private String dsComponentType = new String();
    public String browserDescription = new String("Browser");
    public String printDescription= new String("Print");
    public String viewerDescription= new String("Viewer");
    public String aboutDescription= new String("About");
    
    private JLabel infoLabel = new JLabel("");
    private JLabel l1 = new JLabel("");
    private JLabel l2 = new JLabel("");
    private JLabel l3 = new JLabel("");
    private JLabel l4 = new JLabel("");
    JPanel p1 = new JPanel();
    JPanel p2 = new JPanel();
    JPanel p3 = new JPanel();
    JPanel p4 = new JPanel();
    
    GridBagConstraints gbc = new GridBagConstraints();
    
    public StatusLine(String dsComponentType)
    {
        super();
        
        Controller.instance().addStatusListener(this);
        Controller.instance().addMainListener(this);
        
        setLayout(new GridBagLayout());
        gbc.anchor = GridBagConstraints.WEST;
        gbc.weightx = 2.0;
        gbc.gridwidth = 1;
        gbc.fill = GridBagConstraints.BOTH;
        //setBorder(BorderFactory.createLineBorder(Color.gray));
        


        JLabel sizeLabel = new JLabel("M");
        JPanel p =new JPanel(new FlowLayout(FlowLayout.LEFT));
        p.setBorder(BorderFactory.createEtchedBorder());
        infoLabel.setHorizontalTextPosition(JLabel.LEFT);
        p.add(infoLabel);
        add(p,gbc);
        
        sizeLabel = new JLabel("c/w: 99999999/99999999");
        l1.setPreferredSize(sizeLabel.getPreferredSize());
        p1.setBorder(BorderFactory.createEtchedBorder());
        p1.add(l1);
        
        sizeLabel = new JLabel("Z: MM.MM, da: (+999/-9999)/(+999/-999)");
        l2.setPreferredSize(sizeLabel.getPreferredSize());
        p2.setBorder(BorderFactory.createEtchedBorder());
        p2.add(l2);
        
        sizeLabel = new JLabel("MMMMMMMMMMMM");
        l3.setPreferredSize(sizeLabel.getPreferredSize());
        p3.setBorder(BorderFactory.createEtchedBorder());
        p3.add(l3);
        
        sizeLabel = new JLabel("MMMMMMMMMMMM");
        p4.setPreferredSize(sizeLabel.getPreferredSize());
        p4.setBorder(BorderFactory.createEtchedBorder());
        p4.add(l4);
        
        if (dsComponentType.equals(DSComponentType.VIEWER)) setViewerInfo();
        else changeView(dsComponentType);
        
        
    }
    private void setViewerInfo()
    {
        gbc.weightx = 0.0;
        gbc.fill = GridBagConstraints.NONE;
        add(p1,gbc);
        add(p2,gbc);
        add(p3,gbc);
       //add(p4,gbc);
        infoLabel.setText(viewerDescription);
        
        
    }
    public void changeView(String dsComponentType)
    {
        if (!dsComponentType.equals(this.dsComponentType))
        {
            if (this.dsComponentType.equals(DSComponentType.VIEWER))
            {
                remove(p1);
                remove(p2);
                remove(p3);
                repaint();
            }
            if (dsComponentType.equals(DSComponentType.VIEWER))setViewerInfo();
            else if (dsComponentType.equals(DSComponentType.BROWSER))infoLabel.setText(browserDescription);
            else if (dsComponentType.equals(DSComponentType.ABOUT))infoLabel.setText(aboutDescription);
            else if (dsComponentType.equals(DSComponentType.PRINT))infoLabel.setText(printDescription);
        }
        this.dsComponentType= dsComponentType;
    }
    public boolean processStatus (DSEvent e)
    {
        if (e instanceof StatusLineEvent)
        {
            StatusLineEvent ste =(StatusLineEvent)e;
            infoLabel.setText(ste.description);
            if (ste.dsComponentType ==DSComponentType.VIEWER) 
            {
                viewerDescription = ste.description;
                if (ste.text1 != null) l1.setText(ste.text1);
                if (ste.text2 != null) l2.setText(ste.text2);
                if (ste.text3 != null) l3.setText(ste.text3);
                if (ste.text4 != null) l4.setText(ste.text4);
                
            }
            if (ste.dsComponentType ==DSComponentType.BROWSER) browserDescription = ste.description;
            if (ste.dsComponentType ==DSComponentType.ABOUT) aboutDescription = ste.description;
            if (ste.dsComponentType ==DSComponentType.PRINT) printDescription = ste.description;
            return true;
        }
        
        return false;
    }
	public boolean processEvent (DSEvent e)
	{
	    if (e instanceof TabbedChangeEvent)
	    {
	        changeView(((TabbedChangeEvent)e).getTabbedTitle());
	    }
	    return false;
	}
    
}
/*
 *  CVS Log
 *  $Log: StatusLine.java,v $
 *  Revision 1.1.1.1  2000/06/02 07:02:14  Kleber
 *  new CVS init
 *
 *  Revision 1.2  2000/03/17 14:07:55  kleber
 *  chg: Layout texts on GUI
 *
 *  Revision 1.1.1.1  2000/03/13 14:39:52  kleber
 *  init log for first free release
 *
 *
*/
